@@ -11,37 +11,21 @@
 #include "dbusprovider.h"
 #include "font.h"
 #include "imconfig.h"
+#include <KPluginMetaData>
+#include <KQuickConfigModule>
 #include <QFont>
 #include <QMap>
+#include <QObject>
+#include <QString>
 #include <fcitx-utils/color.h>
 #include <fcitx-utils/key.h>
 #include <layoutprovider.h>
+#include <memory>
 #include <xkbcommon/xkbcommon.h>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <KQuickConfigModule>
-#define FCITX_USE_NEW_KDECLARATIVE
-#else
-#include <KQuickAddons/ConfigModule>
-#include <kdeclarative_version.h>
+namespace fcitx::kcm {
 
-#if KDECLARATIVE_VERSION >= QT_VERSION_CHECK(5, 104, 0)
-#define FCITX_USE_NEW_KDECLARATIVE
-#endif
-
-#endif
-
-namespace fcitx {
-
-namespace kcm {
-
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-using FcitxKCMBase = KQuickConfigModule;
-#else
-using FcitxKCMBase = KQuickAddons::ConfigModule;
-#endif
-
-class FcitxModule : public FcitxKCMBase {
+class FcitxModule : public KQuickConfigModule {
     Q_OBJECT
     Q_PROPERTY(IMConfig *imConfig READ imConfig CONSTANT)
     Q_PROPERTY(LayoutProvider *layoutProvider READ layoutProvider CONSTANT)
@@ -49,14 +33,7 @@ class FcitxModule : public FcitxKCMBase {
     Q_PROPERTY(bool availability READ availability NOTIFY availabilityChanged)
     Q_PROPERTY(bool canRestart READ canRestart NOTIFY canRestartChanged)
 public:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     FcitxModule(QObject *parent, const KPluginMetaData &metaData);
-#elif defined(FCITX_USE_NEW_KDECLARATIVE)
-    FcitxModule(QObject *parent, const KPluginMetaData &metaData,
-                const QVariantList &args);
-#else
-    FcitxModule(QObject *parent, const QVariantList &args);
-#endif
     virtual ~FcitxModule() override;
 
     auto imConfig() const { return imConfig_; }
@@ -112,7 +89,7 @@ public Q_SLOTS:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
     QString eventToString(bool keyCode);
-    QString localizedKeyString(const QString &key);
+    QString localizedKeyString(const QString &str);
 
     void runFcitx();
     void fixLayout();
@@ -135,17 +112,17 @@ private:
     QMap<int, QPointer<QQuickItem>> pages_;
     struct XKBStateDeleter {
         void operator()(struct xkb_state *state) const {
-            return xkb_state_unref(state);
+            xkb_state_unref(state);
         }
     };
     struct XKBKeymapDeleter {
         void operator()(struct xkb_keymap *keymap) const {
-            return xkb_keymap_unref(keymap);
+            xkb_keymap_unref(keymap);
         }
     };
     struct XKBContextDeleter {
         void operator()(struct xkb_context *context) const {
-            return xkb_context_unref(context);
+            xkb_context_unref(context);
         }
     };
     using ScopedXKBState = std::unique_ptr<struct xkb_state, XKBStateDeleter>;
@@ -159,7 +136,6 @@ private:
     Key key_;
 };
 
-} // namespace kcm
-} // namespace fcitx
+} // namespace fcitx::kcm
 
 #endif // _KCM_FCITX5_KCM_NG_MAIN_H_
