@@ -103,13 +103,8 @@ static QString languageName(const QString &langCode) {
             return langCode;
         }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         const bool hasTerritory = (langCode.indexOf("_") != -1 &&
                                    locale.territory() != QLocale::AnyTerritory);
-#else
-        const bool hasTerritory = langCode.indexOf("_") != -1 &&
-                                  locale.country() != QLocale::AnyCountry;
-#endif
         QString languageName;
         if (hasTerritory) {
             languageName = locale.nativeLanguageName();
@@ -126,21 +121,12 @@ static QString languageName(const QString &langCode) {
         // QLocale will always assign a default country for us, check if our
         // lang code
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         if (hasTerritory) {
             territoryName = locale.nativeTerritoryName();
             if (territoryName.isEmpty()) {
                 territoryName = QLocale::territoryToString(locale.territory());
             }
         }
-#else
-        if (hasTerritory) {
-            territoryName = locale.nativeCountryName();
-            if (territoryName.isEmpty()) {
-                territoryName = QLocale::countryToString(locale.country());
-            }
-        }
-#endif
 
         if (territoryName.isEmpty()) {
             return languageName;
@@ -220,7 +206,7 @@ void AvailIMModel::filterIMEntryList(
             idx = filteredIMEntryList.count();
             languageMap[im.languageCode()] = idx;
             filteredIMEntryList.append(
-                QPair<QString, FcitxQtInputMethodEntryList>(
+                std::pair<QString, FcitxQtInputMethodEntryList>(
                     im.languageCode(), FcitxQtInputMethodEntryList()));
         } else {
             idx = languageMap[im.languageCode()];
@@ -405,7 +391,8 @@ QVariant FilteredIMModel::data(const QModelIndex &index, int role) const {
         return QString();
     }
     case FcitxIMActiveRole:
-        return index.row() > 0 ? QString("active") : QString("inactive");
+        return index.row() > 0 ? QStringLiteral("active")
+                               : QStringLiteral("inactive");
 
     default:
         return QVariant();
@@ -442,7 +429,6 @@ void FilteredIMModel::filterIMEntryList(
     // 1. "enabledIMs" is usually very small.
     // 2. CurrentIM mode need to keep order by enabledIMs.
     if (mode_ == CurrentIM) {
-        int row = 0;
         QMap<QString, const FcitxQtInputMethodEntry *> nameMap;
         for (auto &imEntry : imEntryList) {
             nameMap.insert(imEntry.uniqueName(), &imEntry);
@@ -451,7 +437,6 @@ void FilteredIMModel::filterIMEntryList(
         for (const auto &im : enabledIMList) {
             if (auto value = nameMap.value(im.key(), nullptr)) {
                 filteredIMEntryList_.append(*value);
-                row++;
             }
         }
     } else if (mode_ == AvailIM) {
